@@ -579,6 +579,9 @@ class FakeHTTPClient(fakes.FakeHTTPClient):
     def post_share_networks(self, **kwargs):
         return (202, {}, {'share_network': {}})
 
+    def post_share_networks_1234_subnets(self, **kwargs):
+        return (202, {}, {'share_network_subnet': {}})
+
     def post_shares(self, **kwargs):
         return (202, {}, {'share': {}})
 
@@ -609,6 +612,12 @@ class FakeHTTPClient(fakes.FakeHTTPClient):
     def delete_share_networks_fake_share_network2(self, **kwargs):
         return (202, {}, None)
 
+    def delete_share_networks_1234_subnets_fake_subnet1(self, **kwargs):
+        return (202, {}, None)
+
+    def delete_share_networks_1234_subnets_fake_subnet2(self, **kwargs):
+        return (202, {}, None)
+
     def delete_snapshots_fake_snapshot1(self, **kwargs):
         return (202, {}, None)
 
@@ -663,6 +672,14 @@ class FakeHTTPClient(fakes.FakeHTTPClient):
         }
         return (200, {}, share_nw)
 
+    def get_share_networks_1234_subnets_fake_subnet_id(self, **kw):
+        subnet = {
+            'share_network_subnet': {
+                'id': 'fake_subnet_id',
+            },
+        }
+        return (200, {}, subnet)
+
     def get_security_services(self, **kw):
         security_services = {
             'security_services': [
@@ -925,8 +942,9 @@ class FakeHTTPClient(fakes.FakeHTTPClient):
 
     def get_types_1234(self, **kw):
         return (200, {}, {
-            'share_type': {'id': 1,
-                           'name': 'test-type-1',
+            'share_type': {'id': 1234,
+                           'name': 'test-type-1234',
+                           'share_type_access:is_public': True,
                            'description': "test share type desc",
                            'extra_specs': {'test': 'test'},
                            'required_extra_specs': {'test': 'test'}}})
